@@ -90,9 +90,11 @@ double minvweibull(double order, double shape, double scale, int give_log)
         !R_FINITE(shape) ||
         !R_FINITE(order) ||
         scale <= 0.0 ||
-        shape <= 0.0 ||
-        order >= shape)
-        return R_NaN;;
+        shape <= 0.0)
+        return R_NaN;
+
+    if (order >= shape)
+	return R_PosInf;
 
     return R_pow(scale, order) * gammafn(1.0 - order / shape);
 }
@@ -106,12 +108,14 @@ double levinvweibull(double limit, double shape, double scale, double order,
         !R_FINITE(shape) ||
         !R_FINITE(order) ||
         scale <= 0.0 ||
-        shape <= 0.0 ||
-        order >= shape)
-        return R_NaN;;
+        shape <= 0.0)
+        return R_NaN;
+
+    if (order >= shape)
+	return R_PosInf;
 
     if (limit <= 0.0)
-        return 0;
+        return 0.0;
 
     tmp = 1.0 - order / shape;
 
